============================
Sample UCSM Mechanism Driver
============================

This sample configuration file can also be viewed in raw text
:download:`ml2_ucsm.ini.sample <../../_static/config-samples/ml2_ucsm.conf.sample>`.

.. literalinclude:: ../../_static/config-samples/ml2_ucsm.conf.sample
